# Django Cassandra Common

Common classes I have found useful to develop with Django and Cassandra

### Installing

Install using pip

```
pip install django-cassandra-common
```

## Authors

* **Didier Gaona**

## License

This project is licensed under the GNU General Public License v3.0 - see the LICENSE file for details
